Module gradient_block

Module gradient_block 

Re-exports

pub use crate::enums;
pub use crate::structs;
pub use crate::structs::border_segment;
pub use crate::structs::border_symbols;
pub use crate::structs::border_symbols::SegmentSet as SS;
pub use crate::structs::gradient;
pub use crate::types::G;
pub use crate::types::T;
pub use crate::border_styles::*;

Modules

block
Elements related to the Block base widget.
buffer
A module for the Buffer and Cell types.
prelude
A prelude for conveniently writing applications using this library.
text
Primitives for styled text.
widgets
widgets is a collection of types that implement Widget or StatefulWidget or both.

Macros

get_aligned_position
handle_fill

Structs

Block
Base widget to be used to display a box border around all upper level ones.
Borders
Bitflags that can be composed to set the visible borders essentially on the block widget.
GradientBlock
A struct that represents a customizable block with gradient text, borders, and other visual elements.
Line
A line of text, consisting of one or more Spans.
Paragraph
A widget to display some text.
R
A Rectangular area.
Set
Style
Style lets you control the main characteristics of the displayed elements.

Enums

Color
ANSI Color
Position
Defines the title position.

Constants

DOUBLE
Border Set with a double line width
EMPTY
Empty border set
FULL
Solid border set
ONE_EIGHTH_BOTTOM_EIGHT
ONE_EIGHTH_LEFT_EIGHT
ONE_EIGHTH_RIGHT_EIGHT
ONE_EIGHTH_TALL
Tall border set based on McGugan box technique
ONE_EIGHTH_TOP_EIGHT
ONE_EIGHTH_WIDE
Wide border set based on McGugan box technique
PLAIN
Border Set with a single line width
PROPORTIONAL_TALL
Tall proportional (visually equal width and height) border with using set of quadrants.
PROPORTIONAL_WIDE
Wide proportional (visually equal width and height) border with using set of quadrants.
QUADRANT_BLOCK
QUADRANT_BOTTOM_HALF
QUADRANT_BOTTOM_LEFT
QUADRANT_BOTTOM_RIGHT
QUADRANT_INSIDE
Quadrant used for setting a border inside a block by one half cell “pixel”.
QUADRANT_LEFT_HALF
QUADRANT_OUTSIDE
Quadrant used for setting a border outside a block by one half cell “pixel”.
QUADRANT_RIGHT_HALF
QUADRANT_TOP_HALF
QUADRANT_TOP_LEFT
QUADRANT_TOP_LEFT_BOTTOM_LEFT_BOTTOM_RIGHT
QUADRANT_TOP_LEFT_BOTTOM_RIGHT
QUADRANT_TOP_LEFT_TOP_RIGHT_BOTTOM_LEFT
QUADRANT_TOP_LEFT_TOP_RIGHT_BOTTOM_RIGHT
QUADRANT_TOP_RIGHT
QUADRANT_TOP_RIGHT_BOTTOM_LEFT
QUADRANT_TOP_RIGHT_BOTTOM_LEFT_BOTTOM_RIGHT
ROUNDED
Border Set with a single line width and rounded corners
THICK
Border Set with a thick line width

Traits

Widget
A Widget is a type that can be drawn on a Buffer in a given Rect.
WidgetRef
A WidgetRef is a trait that allows rendering a widget by reference.