Position

Struct Position 

pub struct Position {
    pub x: u16,
    pub y: u16,
}
Position in the terminal

The position is relative to the top left corner of the terminal window, with the top left corner being (0, 0). The x axis is horizontal increasing to the right, and the y axis is vertical increasing downwards.

Examples

use ratatui::layout::{Position, Rect};

// the following are all equivalent
let position = Position { x: 1, y: 2 };
let position = Position::new(1, 2);
let position = Position::from((1, 2));
let position = Position::from(Rect::new(1, 2, 3, 4));

// position can be converted back into the components when needed
let (x, y) = position.into();

Fields

x: u16

The x coordinate of the position

The x coordinate is relative to the left edge of the terminal window, with the left edge being 0.

y: u16

The y coordinate of the position

The y coordinate is relative to the top edge of the terminal window, with the top edge being 0.

Implementations

Source

impl Position

pub const ORIGIN: Position

Position at the origin, the top left edge at 0,0

pub const fn new(x: u16, y: u16) -> Position

Create a new position