Re-exports
pub use crate::enums;pub use crate::structs;pub use crate::structs::border_segment;pub use crate::structs::border_symbols;pub use crate::structs::border_symbols::SegmentSet as SS;pub use crate::structs::gradient;pub use crate::types::G;pub use crate::types::T;pub use crate::border_styles::*;
Modules
- block
- Elements related to the
Blockbase widget. - buffer
- A module for the
BufferandCelltypes. - prelude
- A prelude for conveniently writing applications using this library.
- text
- Primitives for styled text.
- widgets
widgetsis a collection of types that implementWidgetorStatefulWidgetor both.
Macros
Structs
- Block
- Base widget to be used to display a box border around all upper level ones.
- Borders
- Bitflags that can be composed to set the visible borders essentially on the block widget.
- Gradient
Block - A struct that represents a customizable block with gradient text, borders, and other visual elements.
- Line
- A line of text, consisting of one or more
Spans. - Paragraph
- A widget to display some text.
- R
- A Rectangular area.
- Set
- Style
- Style lets you control the main characteristics of the displayed elements.
Enums
Constants
- DOUBLE
- Border Set with a double line width
- EMPTY
- Empty border set
- FULL
- Solid border set
- ONE_
EIGHTH_ BOTTOM_ EIGHT - ONE_
EIGHTH_ LEFT_ EIGHT - ONE_
EIGHTH_ RIGHT_ EIGHT - ONE_
EIGHTH_ TALL - Tall border set based on McGugan box technique
- ONE_
EIGHTH_ TOP_ EIGHT - ONE_
EIGHTH_ WIDE - Wide border set based on McGugan box technique
- PLAIN
- Border Set with a single line width
- PROPORTIONAL_
TALL - Tall proportional (visually equal width and height) border with using set of quadrants.
- PROPORTIONAL_
WIDE - Wide proportional (visually equal width and height) border with using set of quadrants.
- QUADRANT_
BLOCK - QUADRANT_
BOTTOM_ HALF - QUADRANT_
BOTTOM_ LEFT - QUADRANT_
BOTTOM_ RIGHT - QUADRANT_
INSIDE - Quadrant used for setting a border inside a block by one half cell “pixel”.
- QUADRANT_
LEFT_ HALF - QUADRANT_
OUTSIDE - Quadrant used for setting a border outside a block by one half cell “pixel”.
- QUADRANT_
RIGHT_ HALF - QUADRANT_
TOP_ HALF - QUADRANT_
TOP_ LEFT - QUADRANT_
TOP_ LEFT_ BOTTOM_ LEFT_ BOTTOM_ RIGHT - QUADRANT_
TOP_ LEFT_ BOTTOM_ RIGHT - QUADRANT_
TOP_ LEFT_ TOP_ RIGHT_ BOTTOM_ LEFT - QUADRANT_
TOP_ LEFT_ TOP_ RIGHT_ BOTTOM_ RIGHT - QUADRANT_
TOP_ RIGHT - QUADRANT_
TOP_ RIGHT_ BOTTOM_ LEFT - QUADRANT_
TOP_ RIGHT_ BOTTOM_ LEFT_ BOTTOM_ RIGHT - ROUNDED
- Border Set with a single line width and rounded corners
- THICK
- Border Set with a thick line width