pub struct BorderStyleInfo {
pub top_left: char,
pub bottom_left: char,
pub top_right: char,
pub bottom_right: char,
pub top: char,
pub bottom: char,
pub left: char,
pub right: char,
pub bottom_center: char,
pub top_center: char,
pub right_center: char,
pub left_center: char,
}Expand description
A struct that defines the characters used for different parts of a border’s visual appearance. Each field specifies a character to represent a particular section of the border.
Fields
top_left: The character used for the top-left corner of the border.bottom_left: The character used for the bottom-left corner of the border.top_right: The character used for the top-right corner of the border.bottom_right: The character used for the bottom-right corner of the border.top: The character used for the top edge of the border.bottom: The character used for the bottom edge of the border.left: The character used for the left side of the border.right: The character used for the right side of the border.bottom_center: The character used for the bottom center section of the border.top_center: The character used for the top center section of the border.right_center: The character used for the right center section of the border.left_center: The character used for the left center section of the border.
Fields
top_left: charbottom_left: chartop_right: charbottom_right: chartop: charbottom: charleft: charright: charbottom_center: chartop_center: charright_center: charleft_center: charAuto Trait Implementations
impl Freeze for BorderStyleInfo
impl RefUnwindSafe for BorderStyleInfo
impl Send for BorderStyleInfo
impl Sync for BorderStyleInfo
impl Unpin for BorderStyleInfo
impl UnwindSafe for BorderStyleInfo